@@ -12,7 +12,7 @@ test_that("multiple variables in one arg doesn't expand", {
   expect_equal(nrow(out), 2)
 })
 
-test_that("nesting doesn't expand values" ,{
+test_that("nesting doesn't expand values", {
   df <- data.frame(x = 1:2, y = 1:2)
   expect_equal(expand(df, nesting(x, y)), df)
 })
@@ -46,14 +46,49 @@ test_that("preserves ordered factors", {
   expect_equal(df$a, ordered("a"))
 })
 
-test_that("zero length inputs are automatically dropped", {
-  tb <- tibble::tibble(x = 1:5)
+test_that("preserves NAs", {
+  x <- c("A", "B", NA)
+  expect_equal(crossing(x)$x, x)
+  expect_equal(nesting(x)$x, x)
+})
+
+test_that("zero length numeric & character inputs are automatically dropped", {
+  tb <- tibble(x = 1:5)
   expect_equal(expand(tb, x, y = numeric()), tb)
   expect_equal(nesting(x = tb$x, y = numeric()), tb)
   expect_equal(crossing(x = tb$x, y = numeric()), tb)
+
+  expect_equal(expand(tb, x, y = character()), tb)
+  expect_equal(nesting(x = tb$x, y = character()), tb)
+  expect_equal(crossing(x = tb$x, y = character()), tb)
+})
+
+test_that("zero length input gives zero length output", {
+  tb <- tibble(x = character())
+  expect_equal(expand(tb, x), tibble())
+  expect_equal(expand(tb, y = NULL), tibble())
+})
+
+test_that("expand & crossing complete zero length factors, nesting doesn't", {
+  tb <- tibble(x = 1:2)
+  emptyfactor <- factor(levels = c("a", "b"))
+  targettb <- tibble(
+    x = as.integer(c(1, 1, 2, 2)),
+    y = factor(c("a", "b", "a", "b"), levels = c("a", "b"))
+  )
+  expect_equal(expand(tb, x, y = emptyfactor), targettb)
+  expect_equal(nesting(x = tb$x, y = emptyfactor), tb)
+  expect_equal(crossing(x = tb$x, y = emptyfactor), targettb)
 })
 
 test_that("expand() reconstructs input dots is empty", {
   expect_is(expand(mtcars), "data.frame")
   expect_is(expand(as_tibble(mtcars)), "tbl_df")
 })
+
+test_that("crossing checks for bad inputs", {
+  expect_error(
+    crossing(x = 1:10, y = quote(a)),
+    "Problems: y"
+  )
+})
